==> haskell-lens-aeson-1.0.2-114-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-LupJJeLTPnW78NXy5PVPay
key: lens-aeson-1.0.2-LupJJeLTPnW78NXy5PVPay
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: 88772592af3d3b69156af166f11449be
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.6.3/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-LupJJeLTPnW78NXy5PVPay
depends:
    aeson-1.4.2.0-G7R46TimzIMEAEOuM4Wcyu
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49 base-4.12.0.0
    bytestring-0.10.8.2 lens-4.17-4smflj6z3lcKQ5thNtBgq9
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    unordered-containers-0.2.10.0-HO72tBDce9GHcBPxpae42I
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.0.2-115-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-L2olA8ediTIVQJSyC9LLm
key: lens-aeson-1.0.2-L2olA8ediTIVQJSyC9LLm
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: 6d711320184edf5537a5e9ea431f3cce
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.6.3/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-L2olA8ediTIVQJSyC9LLm
depends:
    aeson-1.4.2.0-4owspgDf5bB3ddpBjmAUar
    attoparsec-0.13.2.2-Jk4D4QRG8ZrHQCpZMillSF base-4.12.0.0
    bytestring-0.10.8.2 lens-4.17-1P5hjvXDtwNEOshwsrdnCw
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
